summaryrefslogtreecommitdiff
path: root/src/mongo/executor/connection_pool.h
diff options
context:
space:
mode:
authorJason Carey <jcarey@argv.me>2015-09-02 16:19:04 -0400
committerJason Carey <jcarey@argv.me>2015-09-09 13:28:53 -0400
commit08557952c61958166265817ca8bd0c991c01dd59 (patch)
tree5095403149b1f1109bd20977429a2c3afb954968 /src/mongo/executor/connection_pool.h
parent80eff9c7d945b0c447261de8733a0fd154e32d27 (diff)
downloadmongo-08557952c61958166265817ca8bd0c991c01dd59.tar.gz
SERVER-19769 Fixups for Connection Pooling
Various fixes for connection pooling
Diffstat (limited to 'src/mongo/executor/connection_pool.h')
-rw-r--r--src/mongo/executor/connection_pool.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/mongo/executor/connection_pool.h b/src/mongo/executor/connection_pool.h
index d5a0332b5cb..d46b18b9812 100644
--- a/src/mongo/executor/connection_pool.h
+++ b/src/mongo/executor/connection_pool.h
@@ -196,7 +196,7 @@ public:
* Indicates that a connection has failed. This will prevent the connection
* from re-entering the connection pool.
*/
- virtual void indicateFailed() = 0;
+ virtual void indicateFailed(Status status) = 0;
/**
* The HostAndPort for the connection. This should be the same as the
@@ -219,10 +219,10 @@ private:
virtual Date_t getLastUsed() const = 0;
/**
* Returns true if the connection is failed. This implies that it should
* not be returned to the pool.
*/
- virtual bool isFailed() const = 0;
+ virtual const Status& getStatus() const = 0;
/**
* Sets up the connection. This should include connection + auth + any
@@ -219,10 +219,10 @@ private:
virtual Date_t getLastUsed() const = 0;
/**
- * Returns true if the connection is failed. This implies that it should
- * not be returned to the pool.
+ * Returns the status associated with the connection. If the status is not
+ * OK, the connection will not be returned to the pool.
*/